@@ -14,9 +14,10 @@ from CharCNN import *
 from PSPNet import *
 from Inpainting import *
 from AdapAttnIC import *
+import requests
 
 device = torch.device('cuda' if torch.cuda.is_available() else 'cpu')
-
+# model_weights = {UNet : }
 def models(name = None):
     if name is None:
         return "No Models loaded"
@@ -26,8 +27,11 @@ def models(name = None):
 def UNet(num_channels = 1, pretrained = False):        # num_channels = 1 if grayscale image else num_channels = 3 if color image
     if pretrained == True:
         model = U_Net(num_channels)
-        url = "https://github.com/Vinayak-VG/ModelZoo_PyPi/releases/download/Weights/U-Net_Image_Seg_Norm.pt"
-        model.load_state_dict(model_zoo.load_url(url))
+        url = 'https://github.com/Vinayak-VG/ModelZoo_PyPi/releases/download/Weights/U-Net_Image_Seg_Norm.pt'
+        r = requests.get(url, allow_redirects=True)
+        open('unet.pt', 'wb').write(r.content)
+        model.load_state_dict(torch.load('unet.pt'))
+        # model.load_state_dict(model_zoo.load_url(url))
         print("Pre-Trained Model Loaded Succesfully")
     else:
         model = U_Net(num_channels)
@@ -38,7 +42,10 @@ def UNetPP(num_channels = 1, pretrained = False):      # num_channels = 1 if gra
     if pretrained == True:
         model = UNet_PP(num_channels, DenseBlock, BasicDownBlock, BasicUpBlock)
         url = "https://github.com/Vinayak-VG/ModelZoo_PyPi/releases/download/Weights/U-Net++.pt"
-        model.load_state_dict(model_zoo.load_url(url))
+        r = requests.get(url, allow_redirects=True)
+        open('unetpp.pt', 'wb').write(r.content)
+        model.load_state_dict(torch.load('unetpp.pt'))
+        # model.load_state_dict(model_zoo.load_url(url))
         print("Pre-Trained Model Loaded Succesfully")
     else:    
         model = UNet_PP(num_channels, DenseBlock, BasicDownBlock, BasicUpBlock)
